FacebookAccessToken class

Facebook access token.

Constructors

FacebookAccessToken.fromMap(JsonData map)

Properties

authenticationToken String?
OIDC Token.
final
declinedPermissions List<String>
final
expires DateTime
final
hashCode int
The hash code for this object.
no setteroverride
isLimitedLogin bool
true if login was in Limited Login mode.
final
permissions List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
Access token.
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override